# OctoprintPrinterFlagsRequest


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**operational** | **bool** |  | 
**printing** | **bool** |  | 
**cancelling** | **bool** |  | 
**pausing** | **bool** |  | 
**resuming** | **bool** |  | 
**finishing** | **bool** |  | 
**closed_or_error** | **bool** |  | 
**error** | **bool** |  | 
**paused** | **bool** |  | 
**ready** | **bool** |  | 
**sd_ready** | **bool** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


